@@ -3,5 +3,5 @@ var searchData=
   ['pair_20tvp_20parsing_0',['Tag-Value Pair (TVP) Parsing',['../group__module__tvp.html',1,'']]],
   ['parsing_1',['Tag-Value Pair (TVP) Parsing',['../group__module__tvp.html',1,'']]],
   ['point_20arithmetic_2',['Fixed-Point Arithmetic',['../group__module__fixed.html',1,'']]],
-  ['processing_3',['processing',['../group__module__getopt.html',1,'Command-Line Interface (CLI) Option Processing'],['../group__module__string.html',1,'String Processing']]]
+  ['processing_3',['Processing',['../group__module__getopt.html',1,'Command-Line Interface (CLI) Option Processing'],['../group__module__string.html',1,'String Processing']]]
 ];
